# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.tick.v2 import get_tick_pb2 as systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2


class TickServiceStub(object):
    """Called to request tick prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.TickScalarStream = channel.unary_stream(
                '/systemathics.apis.services.tick.v2.TickService/TickScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickScalarStreamResponse.FromString,
                )
        self.TickVectorStream = channel.unary_stream(
                '/systemathics.apis.services.tick.v2.TickService/TickVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.FromString,
                )
        self.TickVectorKeyStream = channel.unary_stream(
                '/systemathics.apis.services.tick.v2.TickService/TickVectorKeyStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorKeyRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.FromString,
                )
        self.TickFields = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickService/TickFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickFieldsResponse.FromString,
                )
        self.TickAssetProviders = channel.unary_unary(
                '/systemathics.apis.services.tick.v2.TickService/TickAssetProviders',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickAssetProvidersResponse.FromString,
                )


class TickServiceServicer(object):
    """Called to request tick prices data. 
    """

    def TickScalarStream(self, request, context):
        """Gets tick historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickVectorStream(self, request, context):
        """Gets tick historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickVectorKeyStream(self, request, context):
        """Gets tick historical data timeseries by identifier and key using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickFields(self, request, context):
        """Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TickAssetProviders(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TickServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'TickScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TickScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickScalarStreamResponse.SerializeToString,
            ),
            'TickVectorStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TickVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.SerializeToString,
            ),
            'TickVectorKeyStream': grpc.unary_stream_rpc_method_handler(
                    servicer.TickVectorKeyStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorKeyRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.SerializeToString,
            ),
            'TickFields': grpc.unary_unary_rpc_method_handler(
                    servicer.TickFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickFieldsResponse.SerializeToString,
            ),
            'TickAssetProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.TickAssetProviders,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickAssetProvidersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.tick.v2.TickService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TickService(object):
    """Called to request tick prices data. 
    """

    @staticmethod
    def TickScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v2.TickService/TickScalarStream',
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickVectorStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v2.TickService/TickVectorStream',
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickVectorKeyStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.tick.v2.TickService/TickVectorKeyStream',
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorKeyRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickService/TickFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TickAssetProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.tick.v2.TickService/TickAssetProviders',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_tick_dot_v2_dot_get__tick__pb2.TickAssetProvidersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from systemathics.apis.services.intraday.v2 import get_intraday_scalar_pb2 as systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2


class IntradayServiceStub(object):
    """Called to request intraday prices data. 
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.IntradayScalarStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayScalarStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.FromString,
                )
        self.IntradayVectorStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
                )
        self.IntradayVectorKeyStream = channel.unary_stream(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorKeyStream',
                request_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
                )
        self.IntradayFields = channel.unary_unary(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayFields',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.FromString,
                )
        self.IntradayAssetProviders = channel.unary_unary(
                '/systemathics.apis.services.intraday.v2.IntradayService/IntradayAssetProviders',
                request_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
                response_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.FromString,
                )


class IntradayServiceServicer(object):
    """Called to request intraday prices data. 
    """

    def IntradayScalarStream(self, request, context):
        """Gets intraday historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayVectorStream(self, request, context):
        """Gets intraday historical data timeseries by identifier using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayVectorKeyStream(self, request, context):
        """Gets intraday historical data timeseries by identifier and key using streaming
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayFields(self, request, context):
        """Gets all available fields by asset and provider.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def IntradayAssetProviders(self, request, context):
        """Gets all available provider by asset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_IntradayServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'IntradayScalarStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayScalarStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.SerializeToString,
            ),
            'IntradayVectorStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayVectorStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.SerializeToString,
            ),
            'IntradayVectorKeyStream': grpc.unary_stream_rpc_method_handler(
                    servicer.IntradayVectorKeyStream,
                    request_deserializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.SerializeToString,
            ),
            'IntradayFields': grpc.unary_unary_rpc_method_handler(
                    servicer.IntradayFields,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.SerializeToString,
            ),
            'IntradayAssetProviders': grpc.unary_unary_rpc_method_handler(
                    servicer.IntradayAssetProviders,
                    request_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                    response_serializer=systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'systemathics.apis.services.intraday.v2.IntradayService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class IntradayService(object):
    """Called to request intraday prices data. 
    """

    @staticmethod
    def IntradayScalarStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayScalarStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayScalarStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayVectorStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayVectorKeyStream(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayVectorKeyStream',
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorKeyRequest.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayVectorStreamResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayFields(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayFields',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayFieldsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def IntradayAssetProviders(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/systemathics.apis.services.intraday.v2.IntradayService/IntradayAssetProviders',
            google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            systemathics_dot_apis_dot_services_dot_intraday_dot_v2_dot_get__intraday__scalar__pb2.IntradayAssetProvidersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/set_tick_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8systemathics/apis/services/tick/v2/set_tick_scalar.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xbb\x01\n\x14SetTickScalarRequest\x12K\n\x04info\x18\x01 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarInfoH\x00R\x04info\x12K\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.systemathics.apis.services.tick.v2.SetTickScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"~\n\x16\x43learTickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\"\xbc\x01\n\x11SetTickScalarInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12\x41\n\x04mode\x18\x03 \x01(\x0e\x32-.systemathics.apis.type.shared.v2.SetDataModeR\x04mode\"Z\n\x11SetTickScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta2\x86\x02\n\x14SetTickScalarService\x12u\n\rSetTickScalar\x12\x38.systemathics.apis.services.tick.v2.SetTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x10\x82\xd3\xe4\x93\x02\n\"\x08/v2/tick(\x01\x12w\n\x0f\x43learTickScalar\x12:.systemathics.apis.services.tick.v2.ClearTickScalarRequest\x1a\x16.google.protobuf.Empty\"\x10\x82\xd3\xe4\x93\x02\n*\x08/v2/tickB\xe9\x01\n&com.systemathics.apis.services.tick.v2B\x12SetTickScalarProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.set_tick_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\022SetTickScalarProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['SetTickScalar']._options = None
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['SetTickScalar']._serialized_options = b'\202\323\344\223\002\n\"\010/v2/tick'
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['ClearTickScalar']._options = None
  _globals['_SETTICKSCALARSERVICE'].methods_by_name['ClearTickScalar']._serialized_options = b'\202\323\344\223\002\n*\010/v2/tick'
  _globals['_SETTICKSCALARREQUEST']._serialized_start=417
  _globals['_SETTICKSCALARREQUEST']._serialized_end=604
  _globals['_CLEARTICKSCALARREQUEST']._serialized_start=606
  _globals['_CLEARTICKSCALARREQUEST']._serialized_end=732
  _globals['_SETTICKSCALARINFO']._serialized_start=735
  _globals['_SETTICKSCALARINFO']._serialized_end=923
  _globals['_SETTICKSCALARDATA']._serialized_start=925
  _globals['_SETTICKSCALARDATA']._serialized_end=1015
  _globals['_SETTICKSCALARSERVICE']._serialized_start=1018
  _globals['_SETTICKSCALARSERVICE']._serialized_end=1280
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/intraday/v2/set_intraday_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import date_interval_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_date__interval__pb2
from systemathics.apis.type.shared.v1 import sampling_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_sampling__pb2
from systemathics.apis.type.shared.v2 import set_data_mode_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v2_dot_set__data__mode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@systemathics/apis/services/intraday/v2/set_intraday_scalar.proto\x12&systemathics.apis.services.intraday.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x34systemathics/apis/type/shared/v1/date_interval.proto\x1a/systemathics/apis/type/shared/v1/sampling.proto\x1a\x34systemathics/apis/type/shared/v2/set_data_mode.proto\"\xfc\x02\n\x18SetIntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x31\n\x08\x64\x61tetime\x18\x03 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12^\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32J.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xcf\x01\n\x1eSetIntradayScalarStreamRequest\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x37.systemathics.apis.services.intraday.v2.SetIntradayInfoH\x00R\x04info\x12S\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayScalarDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\x8e\x03\n\x18SetIntradayVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x31\n\x08\x64\x61tetime\x18\x03 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x04 \x01(\tR\x03key\x12^\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32J.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest.DataEntryR\x04\x64\x61ta\x1a\x37\n\tDataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x01R\x05value:\x02\x38\x01\"\xcf\x01\n\x1eSetIntradayVectorStreamRequest\x12M\n\x04info\x18\x01 \x01(\x0b\x32\x37.systemathics.apis.services.intraday.v2.SetIntradayInfoH\x00R\x04info\x12S\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.systemathics.apis.services.intraday.v2.SetIntradayVectorDataH\x00R\x04\x64\x61taB\t\n\x07payload\"\xf8\x01\n\x1b\x44\x65leteIntradayScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\x12+\n\x05\x64\x61tes\x18\x04 \x03(\x0b\x32\x15.google.type.DateTimeR\x05\x64\x61tes\"\x92\x02\n\x1b\x44\x65leteIntradayVectorRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\x12\x45\n\x04keys\x18\x04 \x03(\x0b\x32\x31.systemathics.apis.services.intraday.v2.VectorKeyR\x04keys\"\xbf\x01\n\x0fSetIntradayInfo\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x46\n\x08sampling\x18\x02 \x01(\x0e\x32*.systemathics.apis.type.shared.v1.SamplingR\x08sampling\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields\"^\n\x15SetIntradayScalarData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"P\n\tVectorKey\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\"p\n\x15SetIntradayVectorData\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x10\n\x03key\x18\x02 \x01(\tR\x03key\x12\x12\n\x04\x64\x61ta\x18\x03 \x03(\x01R\x04\x64\x61ta2\xee\x0b\n\x12SetIntradayService\x12\x8c\x01\n\x13WriteIntradayScalar\x12@.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_scalar\x12\x9a\x01\n\x19WriteIntradayScalarStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_scalar(\x01\x12\x8c\x01\n\x13WriteIntradayVector\x12@.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_vector\x12\x9a\x01\n\x19WriteIntradayVectorStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x13/v2/intraday_vector(\x01\x12\x8d\x01\n\x14UpdateIntradayScalar\x12@.systemathics.apis.services.intraday.v2.SetIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_scalar\x12\x9b\x01\n\x1aUpdateIntradayScalarStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayScalarStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_scalar(\x01\x12\x8d\x01\n\x14UpdateIntradayVector\x12@.systemathics.apis.services.intraday.v2.SetIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_vector\x12\x9b\x01\n\x1aUpdateIntradayVectorStream\x12\x46.systemathics.apis.services.intraday.v2.SetIntradayVectorStreamRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15\x1a\x13/v2/intraday_vector(\x01\x12\x90\x01\n\x14\x44\x65leteIntradayScalar\x12\x43.systemathics.apis.services.intraday.v2.DeleteIntradayScalarRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x13/v2/intraday_scalar\x12\x90\x01\n\x14\x44\x65leteIntradayVector\x12\x43.systemathics.apis.services.intraday.v2.DeleteIntradayVectorRequest\x1a\x16.google.protobuf.Empty\"\x1b\x82\xd3\xe4\x93\x02\x15*\x13/v2/intraday_vectorB\x81\x02\n*com.systemathics.apis.services.intraday.v2B\x16SetIntradayScalarProtoP\x01\xa2\x02\x04SASI\xaa\x02&Systemathics.Apis.Services.Intraday.V2\xca\x02&Systemathics\\Apis\\Services\\Intraday\\V2\xe2\x02\x32Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\xea\x02*Systemathics::Apis::Services::Intraday::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.intraday.v2.set_intraday_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n*com.systemathics.apis.services.intraday.v2B\026SetIntradayScalarProtoP\001\242\002\004SASI\252\002&Systemathics.Apis.Services.Intraday.V2\312\002&Systemathics\\Apis\\Services\\Intraday\\V2\342\0022Systemathics\\Apis\\Services\\Intraday\\V2\\GPBMetadata\352\002*Systemathics::Apis::Services::Intraday::V2'
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._options = None
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._options = None
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_options = b'8\001'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalar']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalarStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayScalarStream']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVector']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVectorStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['WriteIntradayVectorStream']._serialized_options = b'\202\323\344\223\002\025\"\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalar']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalarStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayScalarStream']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVector']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVectorStream']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['UpdateIntradayVectorStream']._serialized_options = b'\202\323\344\223\002\025\032\023/v2/intraday_vector'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayScalar']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayScalar']._serialized_options = b'\202\323\344\223\002\025*\023/v2/intraday_scalar'
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayVector']._options = None
  _globals['_SETINTRADAYSERVICE'].methods_by_name['DeleteIntradayVector']._serialized_options = b'\202\323\344\223\002\025*\023/v2/intraday_vector'
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_start=480
  _globals['_SETINTRADAYSCALARREQUEST']._serialized_end=860
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_start=805
  _globals['_SETINTRADAYSCALARREQUEST_DATAENTRY']._serialized_end=860
  _globals['_SETINTRADAYSCALARSTREAMREQUEST']._serialized_start=863
  _globals['_SETINTRADAYSCALARSTREAMREQUEST']._serialized_end=1070
  _globals['_SETINTRADAYVECTORREQUEST']._serialized_start=1073
  _globals['_SETINTRADAYVECTORREQUEST']._serialized_end=1471
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_start=805
  _globals['_SETINTRADAYVECTORREQUEST_DATAENTRY']._serialized_end=860
  _globals['_SETINTRADAYVECTORSTREAMREQUEST']._serialized_start=1474
  _globals['_SETINTRADAYVECTORSTREAMREQUEST']._serialized_end=1681
  _globals['_DELETEINTRADAYSCALARREQUEST']._serialized_start=1684
  _globals['_DELETEINTRADAYSCALARREQUEST']._serialized_end=1932
  _globals['_DELETEINTRADAYVECTORREQUEST']._serialized_start=1935
  _globals['_DELETEINTRADAYVECTORREQUEST']._serialized_end=2209
  _globals['_SETINTRADAYINFO']._serialized_start=2212
  _globals['_SETINTRADAYINFO']._serialized_end=2403
  _globals['_SETINTRADAYSCALARDATA']._serialized_start=2405
  _globals['_SETINTRADAYSCALARDATA']._serialized_end=2499
  _globals['_VECTORKEY']._serialized_start=2501
  _globals['_VECTORKEY']._serialized_end=2581
  _globals['_SETINTRADAYVECTORDATA']._serialized_start=2583
  _globals['_SETINTRADAYVECTORDATA']._serialized_end=2695
  _globals['_SETINTRADAYSERVICE']._serialized_start=2698
  _globals['_SETINTRADAYSERVICE']._serialized_end=4216
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: systemathics/apis/services/tick/v2/get_tick_scalar.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.type import datetime_pb2 as google_dot_type_dot_datetime__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from systemathics.apis.type.shared.v1 import asset_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_asset__pb2
from systemathics.apis.type.shared.v1 import identifier_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_identifier__pb2
from systemathics.apis.type.shared.v1 import constraints_pb2 as systemathics_dot_apis_dot_type_dot_shared_dot_v1_dot_constraints__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8systemathics/apis/services/tick/v2/get_tick_scalar.proto\x12\"systemathics.apis.services.tick.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1agoogle/type/datetime.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a,systemathics/apis/type/shared/v1/asset.proto\x1a\x31systemathics/apis/type/shared/v1/identifier.proto\x1a\x32systemathics/apis/type/shared/v1/constraints.proto\"\xca\x01\n\x11TickScalarRequest\x12L\n\nidentifier\x18\x01 \x01(\x0b\x32,.systemathics.apis.type.shared.v1.IdentifierR\nidentifier\x12\x16\n\x06\x66ields\x18\x02 \x03(\tR\x06\x66ields\x12O\n\x0b\x63onstraints\x18\x03 \x01(\x0b\x32-.systemathics.apis.type.shared.v1.ConstraintsR\x0b\x63onstraints\"\xc7\x01\n\x18TickScalarStreamResponse\x12P\n\x04info\x18\x01 \x01(\x0b\x32:.systemathics.apis.services.tick.v2.TickScalarStreamFieldsH\x00R\x04info\x12N\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x38.systemathics.apis.services.tick.v2.TickScalarStreamItemH\x00R\x04\x64\x61taB\t\n\x07payload\"0\n\x16TickScalarStreamFields\x12\x16\n\x06\x66ields\x18\x01 \x03(\tR\x06\x66ields\"]\n\x14TickScalarStreamItem\x12\x31\n\x08\x64\x61tetime\x18\x01 \x01(\x0b\x32\x15.google.type.DateTimeR\x08\x64\x61tetime\x12\x12\n\x04\x64\x61ta\x18\x02 \x03(\x01R\x04\x64\x61ta\"~\n\x1fTickScalarAssetProviderResponse\x12[\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32G.systemathics.apis.services.tick.v2.TickScalarAssetProviderItemResponseR\x04\x64\x61ta\"\x8d\x01\n#TickScalarAssetProviderItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\"p\n\x18TickScalarFieldsResponse\x12T\n\x04\x64\x61ta\x18\x01 \x03(\x0b\x32@.systemathics.apis.services.tick.v2.TickScalarFieldsItemResponseR\x04\x64\x61ta\"\x9e\x01\n\x1cTickScalarFieldsItemResponse\x12J\n\nasset_type\x18\x01 \x01(\x0e\x32+.systemathics.apis.type.shared.v1.AssetTypeR\tassetType\x12\x1a\n\x08provider\x18\x02 \x01(\tR\x08provider\x12\x16\n\x06\x66ields\x18\x03 \x03(\tR\x06\x66ields2\xe1\x03\n\x11TickScalarService\x12\xa3\x01\n\x10TickScalarStream\x12\x35.systemathics.apis.services.tick.v2.TickScalarRequest\x1a<.systemathics.apis.services.tick.v2.TickScalarStreamResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/v2/tick_scalar/0\x01\x12\x89\x01\n\x10TickScalarFields\x12\x16.google.protobuf.Empty\x1a<.systemathics.apis.services.tick.v2.TickScalarFieldsResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v2/tick_scalar_fields/\x12\x99\x01\n\x17TickScalarAssetProvider\x12\x16.google.protobuf.Empty\x1a\x43.systemathics.apis.services.tick.v2.TickScalarAssetProviderResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v2/tick_scalar_provider/B\xe9\x01\n&com.systemathics.apis.services.tick.v2B\x12GetTickScalarProtoP\x01\xa2\x02\x04SAST\xaa\x02\"Systemathics.Apis.Services.Tick.V2\xca\x02\"Systemathics\\Apis\\Services\\Tick\\V2\xe2\x02.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\xea\x02&Systemathics::Apis::Services::Tick::V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'systemathics.apis.services.tick.v2.get_tick_scalar_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n&com.systemathics.apis.services.tick.v2B\022GetTickScalarProtoP\001\242\002\004SAST\252\002\"Systemathics.Apis.Services.Tick.V2\312\002\"Systemathics\\Apis\\Services\\Tick\\V2\342\002.Systemathics\\Apis\\Services\\Tick\\V2\\GPBMetadata\352\002&Systemathics::Apis::Services::Tick::V2'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarStream']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarStream']._serialized_options = b'\202\323\344\223\002\022\022\020/v2/tick_scalar/'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarFields']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarFields']._serialized_options = b'\202\323\344\223\002\031\022\027/v2/tick_scalar_fields/'
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarAssetProvider']._options = None
  _globals['_TICKSCALARSERVICE'].methods_by_name['TickScalarAssetProvider']._serialized_options = b'\202\323\344\223\002\033\022\031/v2/tick_scalar_provider/'
  _globals['_TICKSCALARREQUEST']._serialized_start=363
  _globals['_TICKSCALARREQUEST']._serialized_end=565
  _globals['_TICKSCALARSTREAMRESPONSE']._serialized_start=568
  _globals['_TICKSCALARSTREAMRESPONSE']._serialized_end=767
  _globals['_TICKSCALARSTREAMFIELDS']._serialized_start=769
  _globals['_TICKSCALARSTREAMFIELDS']._serialized_end=817
  _globals['_TICKSCALARSTREAMITEM']._serialized_start=819
  _globals['_TICKSCALARSTREAMITEM']._serialized_end=912
  _globals['_TICKSCALARASSETPROVIDERRESPONSE']._serialized_start=914
  _globals['_TICKSCALARASSETPROVIDERRESPONSE']._serialized_end=1040
  _globals['_TICKSCALARASSETPROVIDERITEMRESPONSE']._serialized_start=1043
  _globals['_TICKSCALARASSETPROVIDERITEMRESPONSE']._serialized_end=1184
  _globals['_TICKSCALARFIELDSRESPONSE']._serialized_start=1186
  _globals['_TICKSCALARFIELDSRESPONSE']._serialized_end=1298
  _globals['_TICKSCALARFIELDSITEMRESPONSE']._serialized_start=1301
  _globals['_TICKSCALARFIELDSITEMRESPONSE']._serialized_end=1459
  _globals['_TICKSCALARSERVICE']._serialized_start=1462
  _globals['_TICKSCALARSERVICE']._serialized_end=1943
# @@protoc_insertion_point(module_scope)
